@@ -2362,7 +2362,7 @@ void saphire_rehash()
 ///////////////////////////////////////////////////////
 // ランタイムスクリプト実行
 ///////////////////////////////////////////////////////
-static void read_rc_file()
+static void read_rc_file(BOOL run_user_runtimescript)
 {
     char rc_fname[PATH_MAX];
     snprintf(rc_fname, PATH_MAX,"%s/saphire.sa", SYSCONFDIR);
@@ -2389,29 +2389,31 @@ static void read_rc_file()
     }
 
     /// ユーザーのランタイムスクリプト ////
-    char* user_rc_fname = getenv("SAPHIRE_USERRC");
-    if(user_rc_fname) {
-        if(access(user_rc_fname, R_OK) == 0) {
-            sWFd* pipeout = sWFd_new(STDOUT_FILENO);
-            sRFd* pipein = sRFd_new(STDIN_FILENO);
-            if(saphire_load(user_rc_fname
-                , pipeout, pipein, STDERR_FILENO) < 0)
-            {
-                fprintf(stderr, "%s", string_c_str(gErrMsg));
-                exit(1);
-            }
-            if(!sWFd_flash(pipeout)) {
-                fprintf(stderr, "can't flash rc");
-                exit(1);
-            }
-            sRFd_delete(pipein);
+    if(run_user_runtimescript) {
+        char* user_rc_fname = getenv("SAPHIRE_USERRC");
+        if(user_rc_fname) {
+            if(access(user_rc_fname, R_OK) == 0) {
+                sWFd* pipeout = sWFd_new(STDOUT_FILENO);
+                sRFd* pipein = sRFd_new(STDIN_FILENO);
+                if(saphire_load(user_rc_fname
+                    , pipeout, pipein, STDERR_FILENO) < 0)
+                {
+                    fprintf(stderr, "%s", string_c_str(gErrMsg));
+                    exit(1);
+                }
+                if(!sWFd_flash(pipeout)) {
+                    fprintf(stderr, "can't flash rc");
+                    exit(1);
+                }
+                sRFd_delete(pipein);
 
-            sWFd_delete(pipeout);
+                sWFd_delete(pipeout);
+            }
         }
     }
 }
 
-static void read_rc_obj_file()
+static void read_rc_obj_file(BOOL run_user_runtimescript)
 {
     char rc_fname[PATH_MAX];
     snprintf(rc_fname, PATH_MAX, "%s/saphire.sao", SYSCONFDIR);
@@ -2438,20 +2440,22 @@ static void read_rc_obj_file()
     }
 
     /// ユーザーのランタイムスクリプト ////
-    char* user_rc_fname = getenv("SAPHIRE_USERRC");
-    if(user_rc_fname) {
-        if(access(user_rc_fname, R_OK) == 0) {
-            sWFd* pipeout = sWFd_new(STDOUT_FILENO);
-            sRFd* pipein = sRFd_new(STDIN_FILENO);
-            if(saphire_load_obj(user_rc_fname
-                , pipeout, pipein, STDERR_FILENO) < 0)
-            {
-                fprintf(stderr, "%s", string_c_str(gErrMsg));
-                exit(1);
+    if(run_user_runtimescript) {
+        char* user_rc_fname = getenv("SAPHIRE_USERRC");
+        if(user_rc_fname) {
+            if(access(user_rc_fname, R_OK) == 0) {
+                sWFd* pipeout = sWFd_new(STDOUT_FILENO);
+                sRFd* pipein = sRFd_new(STDIN_FILENO);
+                if(saphire_load_obj(user_rc_fname
+                    , pipeout, pipein, STDERR_FILENO) < 0)
+                {
+                    fprintf(stderr, "%s", string_c_str(gErrMsg));
+                    exit(1);
+                }
+                sWFd_flash(pipeout);
+                sWFd_delete(pipeout);
+                sRFd_delete(pipein);
             }
-            sWFd_flash(pipeout);
-            sWFd_delete(pipeout);
-            sRFd_delete(pipein);
         }
     }
 }
@@ -2459,7 +2463,7 @@ static void read_rc_obj_file()
 ////////////////////////////////////////////////////////
 // 初期化
 ////////////////////////////////////////////////////////
-void saphire_init(enum eAppType app_type, BOOL job_control, enum eRuntimeScript runtime_script)
+void saphire_init(enum eAppType app_type, BOOL job_control, enum eRuntimeScript runtime_script, BOOL run_user_runtimescript)
 {
     gGlobalPipes = VECTOR_NEW(10);
 
@@ -2480,7 +2484,7 @@ void saphire_init(enum eAppType app_type, BOOL job_control, enum eRuntimeScript
     gFileHandles = HASH_NEW(100);
     gReadBuffers = HASH_NEW(100);
 
-    setenv("SAPHIRE_VERSION", "0.9.5", 1);
+    setenv("SAPHIRE_VERSION", "0.9.6", 1);
     setenv("SAPHIRE_PROMPT", "> ", 1);
     setenv("SAPHIRE_DOCDIR", DOCDIR, 1);
     char* home = getenv("HOME");
@@ -2532,11 +2536,11 @@ void saphire_init(enum eAppType app_type, BOOL job_control, enum eRuntimeScript
             break;
 
         case kRSSource:
-            read_rc_file();
+            read_rc_file(run_user_runtimescript);
             break;
 
         case kRSObject:
-            read_rc_obj_file();
+            read_rc_obj_file(run_user_runtimescript);
             break;
     }
     mreset_tty();
